@@ -1,9 +1,11 @@
 package Sah::Schema::perl::modname;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-05-21'; # DATE
+our $DATE = '2020-06-16'; # DATE
 our $DIST = 'Sah-Schemas-Perl'; # DIST
-our $VERSION = '0.032'; # VERSION
+our $VERSION = '0.033'; # VERSION
+
+use Regexp::Pattern::Perl::Module ();
 
 our $schema = [str => {
     summary => 'Perl module name, e.g. Foo::Bar',
@@ -13,7 +15,7 @@ Contains coercion rule so you can also input `Foo-Bar`, `Foo/Bar`, `Foo/Bar.pm`
 or even 'Foo.Bar' and it will be normalized into `Foo::Bar`.
 
 _
-    match => '\A[A-Za-z_][A-Za-z_0-9]*(::[A-Za-z_0-9]+)*\z',
+    match => $Regexp::Pattern::Perl::Module::RE{perl_modname}{pat},
 
     'x.perl.coerce_rules' => [
         'From_str::normalize_perl_modname',
@@ -49,7 +51,7 @@ Sah::Schema::perl::modname - Perl module name, e.g. Foo::Bar
 
 =head1 VERSION
 
-This document describes version 0.032 of Sah::Schema::perl::modname (from Perl distribution Sah-Schemas-Perl), released on 2020-05-21.
+This document describes version 0.033 of Sah::Schema::perl::modname (from Perl distribution Sah-Schemas-Perl), released on 2020-06-16.
 
 =head1 SYNOPSIS
 
